@@ -52,6 +52,7 @@ except ImportError:
       from xml.etree import ElementTree
     except ImportError:
       from elementtree import ElementTree
+import atom
 
 
 class AtomService(object):
@@ -77,6 +78,7 @@ class AtomService(object):
 
   override_token = property(_get_override_token, _set_override_token)
 
+  #@atom.v1_deprecated('Please use atom.client.AtomPubClient instead.')
   def __init__(self, server=None, additional_headers=None, 
       application_name='', http_client=None, token_store=None):
     """Creates a new AtomService client.
@@ -104,6 +106,10 @@ class AtomService(object):
     # If debug is True, the HTTPConnection will display debug information
     self._set_debug(False)
 
+  __init__ = atom.v1_deprecated(
+      'Please use atom.client.AtomPubClient instead.')(
+          __init__)
+
   def _get_debug(self):
     return self.http_client.debug
 
@@ -142,10 +148,14 @@ class AtomService(object):
     """
     self.use_basic_auth(username, password)
 
+  #@atom.v1_deprecated('Please use atom.client.AtomPubClient for requests.')
   def request(self, operation, url, data=None, headers=None, 
       url_params=None):
-    if isinstance(url, str):
-      if not url.startswith('http') and self.ssl:
+    if isinstance(url, (str, unicode)):
+      if url.startswith('http:') and self.ssl:
+        # Force all requests to be https if self.ssl is True.
+        url = atom.url.parse_url('https:' + url[5:])
+      elif not url.startswith('http') and self.ssl: 
         url = atom.url.parse_url('https://%s%s' % (self.server, url))
       elif not url.startswith('http'):
         url = atom.url.parse_url('http://%s%s' % (self.server, url))
@@ -175,6 +185,10 @@ class AtomService(object):
     return auth_token.perform_request(self.http_client, operation, url, 
         data=data, headers=all_headers)
 
+  request = atom.v1_deprecated(
+      'Please use atom.client.AtomPubClient for requests.')(
+          request)
+
   # CRUD operations
   def Get(self, uri, extra_headers=None, url_params=None, escape_params=True):
     """Query the APP server with the given URI
