@@ -15,10 +15,6 @@
 # limitations under the License.
 
 
-# TODO:
-#   add text=none to all inits
-
-
 """Contains extensions to ElementWrapper objects used with Google Calendar."""
 
 
@@ -171,7 +167,6 @@ class CalendarListFeed(gdata.GDataFeed, gdata.LinkFinder):
   _children = gdata.GDataFeed._children.copy()
   _attributes = gdata.GDataFeed._attributes.copy()
   _children['{%s}entry' % atom.ATOM_NAMESPACE] = ('entry', [CalendarListEntry])
-  #_attributes = {}
 
 
 class Scope(atom.AtomBase):
@@ -221,12 +216,10 @@ class CalendarAclEntry(gdata.GDataEntry, gdata.LinkFinder):
                         content=content, atom_id=atom_id, link=link, 
                         published=published, title=title, 
                         updated=updated, text=None)
-
     self.scope = scope
     self.role = role
 
 
-
 class CalendarAclFeed(gdata.GDataFeed, gdata.LinkFinder):
   """A Google Calendar ACL feed flavor of an Atom Feed"""
 
@@ -257,23 +250,9 @@ class CalendarEventCommentFeed(gdata.GDataFeed, gdata.LinkFinder):
       [CalendarEventCommentEntry])
 
 
-class ExtendedProperty(atom.AtomBase):
-  """The Google Calendar extendedProperty element"""
-
-  _tag = 'extendedProperty'
-  _namespace = gdata.GDATA_NAMESPACE
-  _children = atom.AtomBase._children.copy()
-  _attributes = atom.AtomBase._attributes.copy()
-  _attributes['name'] = 'name'
-  _attributes['value'] = 'value'
-
-  def __init__(self, name=None, value=None, extension_elements=None,
-      extension_attributes=None, text=None):
-    self.name = name 
-    self.value = value
-    self.text = text
-    self.extension_elements = extension_elements or []
-    self.extension_attributes = extension_attributes or {}
+class ExtendedProperty(gdata.ExtendedProperty):
+  """A transparent subclass of gdata.ExtendedProperty added to this module
+  for backwards compatibility."""
 
     
 class Reminder(atom.AtomBase):
@@ -287,9 +266,10 @@ class Reminder(atom.AtomBase):
   _attributes['days'] = 'days'
   _attributes['hours'] = 'hours'
   _attributes['minutes'] = 'minutes'
+  _attributes['method'] = 'method'
 
   def __init__(self, absolute_time=None,
-      days=None, hours=None, minutes=None, 
+      days=None, hours=None, minutes=None, method=None,
       extension_elements=None,
       extension_attributes=None, text=None):
     self.absolute_time = absolute_time
@@ -305,6 +285,7 @@ class Reminder(atom.AtomBase):
       self.minutes = str(minutes)
     else:
       self.minutes = None
+    self.method = method
     self.text = text
     self.extension_elements = extension_elements or []
     self.extension_attributes = extension_attributes or {}
@@ -557,17 +538,18 @@ class Who(UriEnumElement):
               'http://schemas.google.com/g/2005#message.reply-to' : 'REPLY_TO',
               'http://schemas.google.com/g/2005#message.to' : 'TO' }
   
-  def __init__(self, extension_elements=None, 
-    extension_attributes=None, text=None):
+  def __init__(self, name=None, email=None, attendee_status=None, 
+      attendee_type=None, rel=None, extension_elements=None, 
+      extension_attributes=None, text=None):
     UriEnumElement.__init__(self, 'who', Who.relEnum, attrib_name='rel',
                             extension_elements=extension_elements,
                             extension_attributes=extension_attributes, 
                             text=text)
-    self.name=None
-    self.email=None
-    self.attendee_status=None
-    self.attendee_type=None
-    self.rel=None
+    self.name = name
+    self.email = email
+    self.attendee_status = attendee_status
+    self.attendee_type = attendee_type
+    self.rel = rel
 
 
 class OriginalEvent(atom.AtomBase):
@@ -685,7 +667,22 @@ class QuickAdd(atom.AtomBase):
       atom.AtomBase._TakeAttributeFromElementTree(self, attribute, 
           element_tree)
 
+
+class Sequence(atom.AtomBase):
+  _tag = 'sequence'
+  _namespace = GCAL_NAMESPACE
+  _children = atom.AtomBase._children.copy()
+  _attributes = atom.AtomBase._attributes.copy()
+  _attributes['value'] = 'value'
           
+  def __init__(self, value=None, extension_elements=None,
+      extension_attributes=None, text=None):
+    self.value = value
+    self.text = text
+    self.extension_elements = extension_elements or []
+    self.extension_attributes = extension_attributes or {}
+
+
 class WebContentGadgetPref(atom.AtomBase):
 
   _tag = 'webContentGadgetPref'
@@ -774,6 +771,8 @@ class CalendarEventEntry(gdata.BatchEntry):
   _children['{%s}comments' % gdata.GDATA_NAMESPACE] = ('comments', Comments)
   _children['{%s}originalEvent' % gdata.GDATA_NAMESPACE] = ('original_event',
                                                             OriginalEvent)
+  _children['{%s}sequence' % GCAL_NAMESPACE] = ('sequence', Sequence)
+  _children['{%s}reminder' % gdata.GDATA_NAMESPACE] = ('reminder', [Reminder])
   
   def __init__(self, author=None, category=None, content=None,
       atom_id=None, link=None, published=None, 
@@ -784,6 +783,7 @@ class CalendarEventEntry(gdata.BatchEntry):
       where=None, when=None, who=None, quick_add=None,
       extended_property=None, original_event=None,
       batch_operation=None, batch_id=None, batch_status=None,
+      sequence=None, reminder=None,
       extension_elements=None, extension_attributes=None, text=None):
 
     gdata.BatchEntry.__init__(self, author=author, category=category, 
@@ -806,6 +806,8 @@ class CalendarEventEntry(gdata.BatchEntry):
     self.quick_add = quick_add
     self.extended_property = extended_property or []
     self.original_event = original_event
+    self.sequence = sequence
+    self.reminder = reminder or []
     self.text = text
     self.extension_elements = extension_elements or []
     self.extension_attributes = extension_attributes or {}
@@ -880,12 +882,13 @@ class CalendarEventFeed(gdata.BatchFeed, gdata.LinkFinder):
   _attributes = gdata.BatchFeed._attributes.copy()
   _children['{%s}entry' % atom.ATOM_NAMESPACE] = ('entry', 
                                                   [CalendarEventEntry])
+  _children['{%s}timezone' % GCAL_NAMESPACE] = ('timezone', Timezone)
 
   def __init__(self, author=None, category=None, contributor=None,
       generator=None, icon=None, atom_id=None, link=None, logo=None, 
       rights=None, subtitle=None, title=None, updated=None, entry=None, 
       total_results=None, start_index=None, items_per_page=None,
-      interrupted=None,
+      interrupted=None, timezone=None,
       extension_elements=None, extension_attributes=None, text=None):
      gdata.BatchFeed.__init__(self, author=author, category=category,
                               contributor=contributor, generator=generator,
@@ -899,6 +902,7 @@ class CalendarEventFeed(gdata.BatchFeed, gdata.LinkFinder):
                               extension_elements=extension_elements,
                               extension_attributes=extension_attributes,
                               text=text)
+     self.timezone = timezone
 
 
 def CalendarListEntryFromString(xml_string):
@@ -923,74 +927,3 @@ def CalendarEventFeedFromString(xml_string):
   
 def CalendarEventCommentFeedFromString(xml_string):
   return atom.CreateClassFromXMLString(CalendarEventCommentFeed, xml_string)
-
-
-# Code to create atom feeds from element trees
-#_CalendarListFeedFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarListFeed, 'feed', atom.ATOM_NAMESPACE)
-#_CalendarListEntryFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarListEntry, 'entry', atom.ATOM_NAMESPACE)
-#_CalendarAclFeedFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarAclFeed, 'feed', atom.ATOM_NAMESPACE)
-#_CalendarAclEntryFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarAclEntry, 'entry', atom.ATOM_NAMESPACE)
-#_CalendarEventFeedFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarEventFeed, 'feed', atom.ATOM_NAMESPACE)
-#_CalendarEventEntryFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarEventEntry, 'entry', atom.ATOM_NAMESPACE)
-#_CalendarEventCommentFeedFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarEventCommentFeed, 'feed', atom.ATOM_NAMESPACE)
-#_CalendarEventCommentEntryFromElementTree = atom._AtomInstanceFromElementTree(
-#    CalendarEventCommentEntry, 'entry', atom.ATOM_NAMESPACE)
-#_WhereFromElementTree = atom._AtomInstanceFromElementTree(
-#    Where, 'where', gdata.GDATA_NAMESPACE)
-#_WhenFromElementTree = atom._AtomInstanceFromElementTree(
-#    When, 'when', gdata.GDATA_NAMESPACE)
-#_WhoFromElementTree = atom._AtomInstanceFromElementTree(
-#    Who, 'who', gdata.GDATA_NAMESPACE)
-#_VisibilityFromElementTree= atom._AtomInstanceFromElementTree(
-#    Visibility, 'visibility', gdata.GDATA_NAMESPACE)
-#_TransparencyFromElementTree = atom._AtomInstanceFromElementTree(
-#    Transparency, 'transparency', gdata.GDATA_NAMESPACE)
-#_CommentsFromElementTree = atom._AtomInstanceFromElementTree(
-#    Comments, 'comments', gdata.GDATA_NAMESPACE)
-#_EventStatusFromElementTree = atom._AtomInstanceFromElementTree(
-#    EventStatus, 'eventStatus', gdata.GDATA_NAMESPACE)
-#_SendEventNotificationsFromElementTree = atom._AtomInstanceFromElementTree(
-#    SendEventNotifications, 'sendEventNotifications', GCAL_NAMESPACE)
-#_QuickAddFromElementTree = atom._AtomInstanceFromElementTree(
-#    QuickAdd, 'quickadd', GCAL_NAMESPACE)
-#_AttendeeStatusFromElementTree = atom._AtomInstanceFromElementTree(
-#    AttendeeStatus, 'attendeeStatus', gdata.GDATA_NAMESPACE)
-#_AttendeeTypeFromElementTree = atom._AtomInstanceFromElementTree(
-#    AttendeeType, 'attendeeType', gdata.GDATA_NAMESPACE)
-#_ExtendedPropertyFromElementTree = atom._AtomInstanceFromElementTree(
-#    ExtendedProperty, 'extendedProperty', gdata.GDATA_NAMESPACE)
-#_RecurrenceFromElementTree = atom._AtomInstanceFromElementTree(
-#    Recurrence, 'recurrence', gdata.GDATA_NAMESPACE)
-#_RecurrenceExceptionFromElementTree = atom._AtomInstanceFromElementTree(
-#    RecurrenceException, 'recurrenceException', gdata.GDATA_NAMESPACE)
-#_OriginalEventFromElementTree = atom._AtomInstanceFromElementTree(
-#    OriginalEvent, 'originalEvent', gdata.GDATA_NAMESPACE)
-#_ColorFromElementTree = atom._AtomInstanceFromElementTree(
-#    Color, 'color', GCAL_NAMESPACE)
-#_HiddenFromElementTree = atom._AtomInstanceFromElementTree(
-#    Hidden, 'hidden', GCAL_NAMESPACE)
-#_SelectedFromElementTree = atom._AtomInstanceFromElementTree(
-#    Selected, 'selected', GCAL_NAMESPACE)
-#_TimezoneFromElementTree = atom._AtomInstanceFromElementTree(
-#    Timezone, 'timezone', GCAL_NAMESPACE)
-#_AccessLevelFromElementTree = atom._AtomInstanceFromElementTree(
-#    AccessLevel, 'accesslevel', GCAL_NAMESPACE)
-#_ReminderFromElementTree = atom._AtomInstanceFromElementTree(
-#    Reminder, 'reminder', gdata.GDATA_NAMESPACE)
-#_ScopeFromElementTree = atom._AtomInstanceFromElementTree(
-#    Scope, 'scope', GACL_NAMESPACE)
-#_RoleFromElementTree = atom._AtomInstanceFromElementTree(
-#    Role, 'role', GACL_NAMESPACE)
-#_WebContentLinkFromElementTree = atom._AtomInstanceFromElementTree(
-#    WebContentLink, 'link', atom.ATOM_NAMESPACE)
-#_WebContentFromElementTree = atom._AtomInstanceFromElementTree(
-#    WebContent, 'webContent', GCAL_NAMESPACE)
-#_WebContentGadgetPrefFromElementTree = atom._AtomInstanceFromElementTree(
-#    WebContentGadgetPref, 'webContentGadgetPref', GCAL_NAMESPACE)
